@@ -74,6 +74,8 @@ class Plugin(Plugin):
                 views.ApiElement.as_view()),
             # url(rx + r'api/(?P<app_label>\w+)/(?P<actor>\w+)/(?P<pk>[^/]+)/(?P<field>\w+)/suggestions$',
             #     views.Suggestions.as_view()),
+            url(rx + r'values/(?P<app_label>\w+)/(?P<actor>\w+)/(?P<pk>.+)/(?P<field>.+)$',
+                views.DelayedValue.as_view()),
             url(rx + r'choices/(?P<app_label>\w+)/(?P<actor>\w+)$',
                 views.Choices.as_view()),
             url(rx + r'choices/(?P<app_label>\w+)/(?P<actor>\w+)/'
