@@ -101,6 +101,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
             use_dashboard_layouts=plugins.system.use_dashboard_layouts,
             )
 
+        if settings.SITE.user_model == None:
+            data.update(no_user_model=True)
+
         if settings.SITE.is_installed('notify'):
             data.update(use_push_api=plugins.notify.use_push_api)
 
@@ -235,13 +238,6 @@ class Renderer(JsRenderer, JsCacheRenderer):
             sar = ar.spawn(ba, **request_kwargs)
         return self.ar2js(sar, obj, **status)
 
-    def get_action_params(self, ar, ba, obj, **kw):
-        if ba.action.parameters:
-            fv = ba.action.params_layout.params_store.pv2list(
-                ar, ar.action_param_values)
-            kw[constants.URL_PARAM_FIELD_VALUES] = fv
-        return kw
-
     def get_action_icon(self, action):
         """
         Uses an internal mapping for icon names to convert existing icons into react-usable.
@@ -419,27 +415,28 @@ class Renderer(JsRenderer, JsCacheRenderer):
         st = ar.get_status(**kw)
         return self.action_call(ar, ar.bound_action, st)
 
-    def instance_handler(self, ar, obj, ba, **status):
-        if ar and hasattr(ar, 'get_status'):
-            status.update(ar.get_status())
-        return super(Renderer, self).instance_handler(ar, obj, ba, **status)
+    # def instance_handler(self, ar, obj, ba, **status):
+    #     return super(Renderer, self).instance_handler(ar, obj, ba, **status)
 
-    def action_call(self, request, bound_action, status):
+    def action_call(self, ar, bound_action, status):
 
         a = bound_action.action
         # fullname = ".".join(bound_action.full_name().rsplit(".", 1)[::-1])  # moves action name to first arg,
         actorId, an = bound_action.full_name().rsplit(".", 1)
 
-        if request and request.subst_user:
-            status[
-                constants.URL_PARAM_SUBST_USER] = request.subst_user
-        if isinstance(a, ShowEmptyTable) and an != 'grid':
-            status.update(record_id=-99998)
-
-        rp = None if request is None else request.requesting_panel
-
         if not status:
             status = {}
+        if ar and ar._status:
+            status.update(ar._status)
+
+        if ar and ar.subst_user:
+            status[constants.URL_PARAM_SUBST_USER] = ar.subst_user
+        if isinstance(a, ShowEmptyTable):
+            status.update(record_id=-99998)
+        if an == 'grid' and hasattr(status, 'record_id'):
+            del status['record_id']
+
+        rp = None if ar is None else ar.requesting_panel
 
         return "window.App.runAction(%s)" % py2js(dict(
             an=an,
